==> jakarta-xml-ws-tck-2.3.0.zip: xml-ws-tck/src/com/sun/ts/tests/jaxws/ee/w2j/document/literal/catalogtest/HelloImpl.java <==
/*
 * Copyright (c) 2007, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

/*
 * $Id$
 */

package com.sun.ts.tests.jaxws.ee.w2j.document.literal.catalogtest;

import javax.xml.ws.WebServiceException;
import javax.jws.WebService;

@WebService(portName = "HelloPort", serviceName = "CatalogTestService", targetNamespace = "http://catalogtestservice.org/wsdl", wsdlLocation = "WEB-INF/wsdl/WSW2JDLCatalogTestService.wsdl", endpointInterface = "com.sun.ts.tests.jaxws.ee.w2j.document.literal.catalogtest.Hello")
public class HelloImpl implements Hello {

  public HelloResponse hello(HelloRequest req) {
    HelloResponse resp = null;
    System.out.println("Hello, " + req.getString() + "!");
    resp = new HelloResponse();
    resp.setString("Hello, " + req.getString() + "!");
    return resp;
  }

  public void helloOneWay(HelloOneWay req) {
    System.out.println("Hello OneWay, " + req.getString() + "!");
  }
}

==> jakarta-xml-ws-tck-3.0.1.zip: xml-ws-tck/src/com/sun/ts/tests/jaxws/ee/w2j/document/literal/catalogtest/HelloImpl.java <==
/*
 * Copyright (c) 2007, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

/*
 * $Id$
 */

package com.sun.ts.tests.jaxws.ee.w2j.document.literal.catalogtest;

import jakarta.xml.ws.WebServiceException;
import jakarta.jws.WebService;

@WebService(portName = "HelloPort", serviceName = "CatalogTestService", targetNamespace = "http://catalogtestservice.org/wsdl", wsdlLocation = "WEB-INF/wsdl/WSW2JDLCatalogTestService.wsdl", endpointInterface = "com.sun.ts.tests.jaxws.ee.w2j.document.literal.catalogtest.Hello")
public class HelloImpl implements Hello {

  public HelloResponse hello(HelloRequest req) {
    HelloResponse resp = null;
    System.out.println("Hello, " + req.getString() + "!");
    resp = new HelloResponse();
    resp.setString("Hello, " + req.getString() + "!");
    return resp;
  }

  public void helloOneWay(HelloOneWay req) {
    System.out.println("Hello OneWay, " + req.getString() + "!");
  }
}
